<?php

namespace Database;
use \PDO;

class AthleteGateway {
    private Connexion $connection;

    public function __construct(Connexion $connection) {
        $this->connection = $connection;
    }

    public function getAthlete(): array
    {
        $query = "SELECT * FROM Athlete WHERE isCoach=NULL";
        return $this->connection->executeWithErrorHandling($query);
    }

    public function getAthleteById(int $userId): array
    {
        $query = "SELECT * FROM Athlete WHERE idAthlete = :id";
        $params = [':id' => [$userId, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByName(string $name): array
    {
        $query = "SELECT * FROM Athlete WHERE nom = :name AND isCoach=NULL";
        $params = [':name' => [$name, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByFirstName(string $firstName): array
    {
        $query = "SELECT * FROM Athlete WHERE prenom = :firstName";
        $params = [':firstName' => [$firstName, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByEmail(string $email): array
    {
        $query = "SELECT * FROM Athlete WHERE email = :email";
        $params = [':email' => [$email, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByGender(string $gender): array
    {
        $query = "SELECT * FROM Athlete WHERE sexe = :gender";
        $params = [':gender' => [$gender, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByHeight(int $height): array
    {
        $query = "SELECT * FROM Athlete WHERE taille = :height";
        $params = [':height' => [$height, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByWeight(int $weight): array
    {
        $query = "SELECT * FROM Athlete WHERE poids = :weight";
        $params = [':weight' => [$weight, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByBirthDate(string $birthdate): array
    {
        $query = "SELECT * FROM Athlete WHERE dateNaissance = :birthdate";
        $params = [':birthdate' => [$birthdate, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByIsCoachTrue(): array
    {
        $query = "SELECT * FROM Athlete WHERE isCoach = TRUE";
        return $this->connection->executeWithErrorHandling($query);
    }

    public function getAthleteByIsCoachFalse(): array
    {
        $query = "SELECT * FROM Athlete WHERE isCoach = FALSE";
        return $this->connection->executeWithErrorHandling($query);
    }

    public function getAthleteByCoachId(int $coachId): array
    {
        $query = "SELECT * FROM Athlete WHERE coachId = :coachId";
        $params = [':coachId' => [$coachId, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function addAthlete(AthleteEntity $athlete): array
    {
        $query = "INSERT INTO Athlete (nom, prenom, email, sexe, taille, poids, motDePasse, dateNaissance, isCoach, coachId) 
                  VALUES (:nom, :prenom, :email, :sexe, :taille, :poids, :motDePasse, :dateNaissance, :isCoach, :coachId)";

        $params = [
            ':nom' => $athlete->getNom(),
            ':prenom' => $athlete->getPrenom(),
            ':email' => $athlete->getEmail(),
            ':sexe' => $athlete->getSexe(),
            ':taille' => $athlete->getTaille(),
            ':poids' => $athlete->getPoids(),
            ':motDePasse' => $athlete->getMotDePasse(),
            ':dateNaissance' => $athlete->getDateNaissance(),
            ':isCoach' => $athlete->getIsCoach(),
            ':coachId' => $athlete->getCoachId(),
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function updateAthlete(AthleteEntity $oldAthlete, AthleteEntity $newAthlete): array
    {
        $query = "UPDATE Athlete 
                  SET nom = :nom, prenom = :prenom, email = :email, sexe = :sexe,
                  taille = :taille, poids = :poids, motDePasse = :motDePasse, dateNaissance = :dateNaissance, isCoach = :isCoach, coachId = :coachId
                  WHERE idAthlete = :idAthlete";

        $params = [
            ':idAthlete' => $oldAthlete->getIdAthlete(),
            ':nom' => $newAthlete->getNom(),
            ':prenom' => $newAthlete->getPrenom(),
            ':email' => $newAthlete->getEmail(),
            ':sexe' => $newAthlete->getSexe(),
            ':taille' => $newAthlete->getTaille(),
            ':poids' => $newAthlete->getPoids(),
            ':motDePasse' => $newAthlete->getMotDePasse(),
            ':dateNaissance' => $newAthlete->getDateNaissance(),
            ':isCoach' => $athlete->getIsCoach(),
            ':coachId' => $athlete->getCoachId(),
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function deleteAthlete(int $idAthlete): array
    {
        $query = "DELETE FROM Athlete WHERE idAthlete = :idAthlete";

        $params = [
            ':idAthlete' => $idAthlete,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }



}


// Exemple d'utilisation
//$dsn = "pgsql:host=localhost;port=5432;dbname=mydatabase;user=myuser;password=mypassword";
//$connection = new Connection($dsn);
//$gateway = new AthleteGateway($connection);

//$allAth = $gateway->getAthlete();
//print_r($allAth);

//$singleAth = $gateway->getAthleteById(1);
//print_r($singleAth);

?>
